@@ -19,12 +19,17 @@
  * <http://www.gnu.org/licenses/>.
  */
 
-#include <QtUiPlugin/QDesignerCustomWidgetInterface>
 #include <QGroupBox>
 #include <QMetaObject>
 #include <QPluginLoader>
 #include <QTest>
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 5, 0)
+#include <QtUiPlugin/QDesignerCustomWidgetInterface>
+#else
+#include <QDesignerCustomWidgetInterface>
+#endif
+
 static bool widgetLessThan(QDesignerCustomWidgetInterface* w1, QDesignerCustomWidgetInterface* w2)
 {
     return w1->name() < w2->name();
